Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var INTERP = resize.Bicubic
Functions ¶
func Ahash ¶
Ahash calculates a hash value for the given image. It implements the Average hash algorithm as explained here: http://www.hackerfactor.com/blog/index.php?/archives/432-Looks-Like-It.html Returns the hash of the image in 64 bits integer.
func Dhash ¶
Dhash calculates a hash value for the given image. It implements the dHash (gradient) algorithm as explained here: http://www.hackerfactor.com/blog/index.php?/archives/529-Kind-of-Like-That.html Returns the hash of the image in 64 bits integer.
func HammingDistance ¶
Types ¶
type ImageSlice ¶
type ImageSlice struct {
// contains filtered or unexported fields
}
Click to show internal directories.
Click to hide internal directories.